@@ -32,15 +32,15 @@
 class WP5TabGroup : public WP5FixedLengthGroup
 {
 public:
-	WP5TabGroup(WPXInputStream *input, uint8_t groupID);	
+	WP5TabGroup(WPXInputStream *input, WPXEncryption *encryption, uint8_t groupID);	
 	void parse(WP5Listener *listener);
 	
 protected:
-	void _readContents(WPXInputStream *input);
+	void _readContents(WPXInputStream *input, WPXEncryption *encryption);
 
 private:
 	uint8_t m_tabType;
-	float m_tabPosition;
+	double m_tabPosition;
 
 };
 
