@@ -42,20 +42,21 @@ public:
 	WP6VariableLengthGroup(); // WP6VariableLengthGroup should _never_ be constructed, only its inherited classes
 	virtual ~WP6VariableLengthGroup();
 
-	static WP6VariableLengthGroup * constructVariableLengthGroup(WPXInputStream *input, const uint8_t groupID);
+	static WP6VariableLengthGroup * constructVariableLengthGroup(WPXInputStream *input, WPXEncryption *encryption, const uint8_t groupID);
 
-	static bool isGroupConsistent(WPXInputStream *input, const uint8_t groupID);
+	static bool isGroupConsistent(WPXInputStream *input, WPXEncryption *encryption, const uint8_t groupID);
 
 protected:
-	void _read(WPXInputStream *input);
-	virtual void _readContents(WPXInputStream * /* input */) {} // we don't always need more information than that provided generically
+	void _read(WPXInputStream *input, WPXEncryption *encryption);
+	virtual void _readContents(WPXInputStream * /* input */, WPXEncryption * /* encryption */) {} // we don't always need more information than that provided generically
 
-	const uint8_t getSubGroup() const { return m_subGroup; }
-	const uint16_t getSize() const { return m_size; }
-	const uint8_t getFlags() const { return m_flags; }
-	const uint8_t getNumPrefixIDs() const { return m_numPrefixIDs; }
-	uint16_t * const getPrefixIDs() const { return m_prefixIDs; }
-	const uint16_t getSizeNonDeletable() const { return m_sizeNonDeletable; }
+	uint8_t getSubGroup() const { return m_subGroup; }
+	uint16_t getSize() const { return m_size; }
+	uint8_t getFlags() const { return m_flags; }
+	uint8_t getNumPrefixIDs() const { return m_numPrefixIDs; }
+	const uint16_t * getPrefixIDs() const { return m_prefixIDs; }
+	uint16_t getSizeNonDeletable() const { return m_sizeNonDeletable; }
+	uint16_t getSizeDeletable() const { return m_sizeDeletable; }
 
 private:
 	WP6VariableLengthGroup(const WP6VariableLengthGroup&);
@@ -66,6 +67,7 @@ private:
 	uint8_t m_numPrefixIDs;
 	uint16_t *m_prefixIDs;
 	uint16_t m_sizeNonDeletable;
+	uint16_t m_sizeDeletable;
 };
 
 #endif /* WP6VARIABLELENGTHGROUP_H */
