@@ -99,8 +99,8 @@ WPXPropertyList::WPXPropertyList() :
 WPXPropertyList::WPXPropertyList(const WPXPropertyList &propList) :
 	m_mapImpl(new WPXMapImpl())
 {
-        WPXPropertyList::Iter i(propList);
-        for (i.rewind(); i.next(); )
+	WPXPropertyList::Iter i(propList);
+	for (i.rewind(); i.next(); )
 	{
 		insert(i.key(), i()->clone());
 	}
@@ -136,16 +136,18 @@ void WPXPropertyList::insert(const char * name, const WPXString &val)
 	m_mapImpl->insert(name, WPXPropertyFactory::newStringProp(val));
 }
 
-void WPXPropertyList::insert(const char * name, const float val, const WPXUnit units)
+void WPXPropertyList::insert(const char * name, const double val, const WPXUnit units)
 { 
-	if (units == INCH)
+	if (units == WPX_INCH)
 		m_mapImpl->insert(name, WPXPropertyFactory::newInchProp(val));
-	else if (units == PERCENT)
+	else if (units == WPX_PERCENT)
 		m_mapImpl->insert(name, WPXPropertyFactory::newPercentProp(val));
-	else if (units == POINT)		
+	else if (units == WPX_POINT)		
 		m_mapImpl->insert(name, WPXPropertyFactory::newPointProp(val));
-	else
+	else if (units == WPX_TWIP)
 		m_mapImpl->insert(name, WPXPropertyFactory::newTwipProp(val));
+	else if (units == WPX_GENERIC)
+		m_mapImpl->insert(name, WPXPropertyFactory::newDoubleProp(val));
 }
 
 void WPXPropertyList::remove(const char * name)
@@ -155,12 +157,13 @@ void WPXPropertyList::remove(const char * name)
 
 const WPXPropertyList& WPXPropertyList::operator=(const WPXPropertyList& propList)
 {
-        WPXPropertyList::Iter i(propList);
-        for (i.rewind(); i.next(); )
-        {
-            insert(i.key(), i()->clone());
-        }
-        return *this;
+    clear();    
+	WPXPropertyList::Iter i(propList);
+	for (i.rewind(); i.next(); )
+	{
+		insert(i.key(), i()->clone());
+	}
+	return *this;
 }
 
 const WPXProperty * WPXPropertyList::operator[](const char *name) const
